==> rsuite-5.62.0.tgz: package/esm/Message/Message.js <==
'use client';
import _extends from "@babel/runtime/helpers/esm/extends";
import _taggedTemplateLiteralLoose from "@babel/runtime/helpers/esm/taggedTemplateLiteralLoose";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _templateObject, _templateObject2, _templateObject3, _templateObject4, _templateObject5;
import React, { useState, useContext } from 'react';
import PropTypes from 'prop-types';
import { STATUS } from "../internals/constants";
import { MESSAGE_STATUS_ICONS } from "../internals/constants/statusIcons";
import { useClassNames, useTimeout, useIsMounted, useEventCallback } from "../internals/hooks";
import { oneOf } from "../internals/propTypes";
import CloseButton from "../internals/CloseButton";
import ToastContext from "../toaster/ToastContext";
/**
 * The `Message` component is used to display important messages to users.
 * @see https://rsuitejs.com/components/message
 */
var Message = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _withClassPrefix;
  var _props$as = props.as,
    Component = _props$as === void 0 ? 'div' : _props$as,
    bordered = props.bordered,
    centered = props.centered,
    className = props.className,
    _props$classPrefix = props.classPrefix,
    classPrefix = _props$classPrefix === void 0 ? 'message' : _props$classPrefix,
    children = props.children,
    closable = props.closable,
    _props$duration = props.duration,
    duration = _props$duration === void 0 ? 2000 : _props$duration,
    full = props.full,
    header = props.header,
    _props$type = props.type,
    type = _props$type === void 0 ? 'info' : _props$type,
    showIcon = props.showIcon,
    onClose = props.onClose,
    rest = _objectWithoutPropertiesLoose(props, ["as", "bordered", "centered", "className", "classPrefix", "children", "closable", "duration", "full", "header", "type", "showIcon", "onClose"]);
  var _useState = useState('show'),
    display = _useState[0],
    setDisplay = _useState[1];
  var _useClassNames = useClassNames(classPrefix),
    withClassPrefix = _useClassNames.withClassPrefix,
    merge = _useClassNames.merge,
    prefix = _useClassNames.prefix;
  var isMounted = useIsMounted();
  var _useContext = useContext(ToastContext),
    usedToaster = _useContext.usedToaster; // Timed close message
  var _useTimeout = useTimeout(onClose, duration, usedToaster && duration > 0),
    clear = _useTimeout.clear;
  var handleClose = useEventCallback(function (event) {
    setDisplay('hiding');
    onClose === null || onClose === void 0 ? void 0 : onClose(event);
    clear();
    setTimeout(function () {
      if (isMounted()) {
        setDisplay('hide');
      }
    }, 1000);
  });
  if (display === 'hide') {
    return null;
  }
  var classes = merge(className, withClassPrefix(type, display, (_withClassPrefix = {
    full: full,
    bordered: bordered,
    centered: centered
  }, _withClassPrefix['has-title'] = header, _withClassPrefix['has-icon'] = showIcon, _withClassPrefix)));
  return /*#__PURE__*/React.createElement(Component, _extends({
    role: "alert"
  }, rest, {
    ref: ref,
    className: classes
  }), /*#__PURE__*/React.createElement("div", {
    className: prefix(_templateObject || (_templateObject = _taggedTemplateLiteralLoose(["container"])))
  }, closable && /*#__PURE__*/React.createElement(CloseButton, {
    onClick: handleClose
  }), showIcon && /*#__PURE__*/React.createElement("div", {
    className: prefix(_templateObject2 || (_templateObject2 = _taggedTemplateLiteralLoose(["icon"])))
  }, MESSAGE_STATUS_ICONS[type]), /*#__PURE__*/React.createElement("div", {
    className: prefix(_templateObject3 || (_templateObject3 = _taggedTemplateLiteralLoose(["content"])))
  }, header && /*#__PURE__*/React.createElement("div", {
    className: prefix(_templateObject4 || (_templateObject4 = _taggedTemplateLiteralLoose(["header"])))
  }, header), children && /*#__PURE__*/React.createElement("div", {
    className: prefix(_templateObject5 || (_templateObject5 = _taggedTemplateLiteralLoose(["body"])))
  }, children))));
});
Message.displayName = 'Message';
Message.propTypes = {
  bordered: PropTypes.bool,
  centered: PropTypes.bool,
  closable: PropTypes.bool,
  className: PropTypes.string,
  classPrefix: PropTypes.string,
  description: PropTypes.node,
  full: PropTypes.bool,
  onClose: PropTypes.func,
  showIcon: PropTypes.bool,
  title: PropTypes.node,
  type: oneOf(STATUS)
};
export default Message;

==> rsuite-5.63.0.tgz: package/esm/Message/Message.js <==
'use client';
import _extends from "@babel/runtime/helpers/esm/extends";
import _taggedTemplateLiteralLoose from "@babel/runtime/helpers/esm/taggedTemplateLiteralLoose";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _templateObject, _templateObject2, _templateObject3, _templateObject4, _templateObject5;
var _excluded = ["as", "bordered", "centered", "className", "classPrefix", "children", "closable", "duration", "full", "header", "type", "showIcon", "onClose"];
import React, { useState, useContext } from 'react';
import PropTypes from 'prop-types';
import { STATUS } from "../internals/constants/index.js";
import { MESSAGE_STATUS_ICONS } from "../internals/constants/statusIcons.js";
import { useClassNames, useTimeout, useIsMounted, useEventCallback } from "../internals/hooks/index.js";
import { oneOf } from "../internals/propTypes/index.js";
import CloseButton from "../internals/CloseButton/index.js";
import ToastContext from "../toaster/ToastContext.js";
/**
 * The `Message` component is used to display important messages to users.
 * @see https://rsuitejs.com/components/message
 */
var Message = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var _withClassPrefix;
  var _props$as = props.as,
    Component = _props$as === void 0 ? 'div' : _props$as,
    bordered = props.bordered,
    centered = props.centered,
    className = props.className,
    _props$classPrefix = props.classPrefix,
    classPrefix = _props$classPrefix === void 0 ? 'message' : _props$classPrefix,
    children = props.children,
    closable = props.closable,
    _props$duration = props.duration,
    duration = _props$duration === void 0 ? 2000 : _props$duration,
    full = props.full,
    header = props.header,
    _props$type = props.type,
    type = _props$type === void 0 ? 'info' : _props$type,
    showIcon = props.showIcon,
    onClose = props.onClose,
    rest = _objectWithoutPropertiesLoose(props, _excluded);
  var _useState = useState('show'),
    display = _useState[0],
    setDisplay = _useState[1];
  var _useClassNames = useClassNames(classPrefix),
    withClassPrefix = _useClassNames.withClassPrefix,
    merge = _useClassNames.merge,
    prefix = _useClassNames.prefix;
  var isMounted = useIsMounted();
  var _useContext = useContext(ToastContext),
    usedToaster = _useContext.usedToaster;

  // Timed close message
  var _useTimeout = useTimeout(onClose, duration, usedToaster && duration > 0),
    clear = _useTimeout.clear;
  var handleClose = useEventCallback(function (event) {
    setDisplay('hiding');
    onClose === null || onClose === void 0 ? void 0 : onClose(event);
    clear();
    setTimeout(function () {
      if (isMounted()) {
        setDisplay('hide');
      }
    }, 1000);
  });
  if (display === 'hide') {
    return null;
  }
  var classes = merge(className, withClassPrefix(type, display, (_withClassPrefix = {
    full: full,
    bordered: bordered,
    centered: centered
  }, _withClassPrefix['has-title'] = header, _withClassPrefix['has-icon'] = showIcon, _withClassPrefix)));
  return /*#__PURE__*/React.createElement(Component, _extends({
    role: "alert"
  }, rest, {
    ref: ref,
    className: classes
  }), /*#__PURE__*/React.createElement("div", {
    className: prefix(_templateObject || (_templateObject = _taggedTemplateLiteralLoose(["container"])))
  }, closable && /*#__PURE__*/React.createElement(CloseButton, {
    onClick: handleClose
  }), showIcon && /*#__PURE__*/React.createElement("div", {
    className: prefix(_templateObject2 || (_templateObject2 = _taggedTemplateLiteralLoose(["icon"])))
  }, MESSAGE_STATUS_ICONS[type]), /*#__PURE__*/React.createElement("div", {
    className: prefix(_templateObject3 || (_templateObject3 = _taggedTemplateLiteralLoose(["content"])))
  }, header && /*#__PURE__*/React.createElement("div", {
    className: prefix(_templateObject4 || (_templateObject4 = _taggedTemplateLiteralLoose(["header"])))
  }, header), children && /*#__PURE__*/React.createElement("div", {
    className: prefix(_templateObject5 || (_templateObject5 = _taggedTemplateLiteralLoose(["body"])))
  }, children))));
});
Message.displayName = 'Message';
Message.propTypes = {
  bordered: PropTypes.bool,
  centered: PropTypes.bool,
  closable: PropTypes.bool,
  className: PropTypes.string,
  classPrefix: PropTypes.string,
  description: PropTypes.node,
  full: PropTypes.bool,
  onClose: PropTypes.func,
  showIcon: PropTypes.bool,
  title: PropTypes.node,
  type: oneOf(STATUS)
};
export default Message;
